@@ -1,5 +1,7 @@
 """Implements checks."""
-from abc import ABC, abstractmethod
+
+from abc import ABC
+from abc import abstractmethod
 from dataclasses import dataclass
 from typing import ClassVar
 
