@@ -1,8 +1,13 @@
 """Implements aggregation of checks."""
-from typing import Generator
 
-from pyvelocity.checks.line_length import LineLength
+from collections.abc import Generator
+
+from pyvelocity.checks import Check
 from pyvelocity.checks import Result
+from pyvelocity.checks.classifiers import Classifiers
+from pyvelocity.checks.line_length import LineLength
+from pyvelocity.checks.readme import Readme
+from pyvelocity.checks.requires_python import RequiresPython
 from pyvelocity.checks.using_py_project_toml import UsingPyProjectToml
 from pyvelocity.configurations.aggregation import Configurations
 from pyvelocity.configurations.files.aggregation import ConfigurationFiles
@@ -27,11 +32,11 @@ class Checks:
     """Aggregation of Check."""
 
     def __init__(self, configuration_files: ConfigurationFiles, configurations: Configurations) -> None:
-        checks = [UsingPyProjectToml, LineLength]
+        check_classes: list[type[Check]] = [UsingPyProjectToml, LineLength, Readme, RequiresPython, Classifiers]
         self.checks = (
-            check(configuration_files, configurations)
-            for check in checks
-            if check.ID not in configurations.pyvelocity.filter.value
+            check_class(configuration_files, configurations)
+            for check_class in check_classes
+            if check_class.ID not in configurations.pyvelocity.filter.value
         )
 
     def execute(self) -> Generator[Result, None, None]:
