@@ -1,5 +1,7 @@
 """Implements configuration files."""
-from abc import ABC, abstractmethod
+
+from abc import ABC
+from abc import abstractmethod
 
 
 class ConfigurationFile(ABC):
